\name{ISOMDS}
\alias{ISOMDS}
\title{A wrapper for the isoMDS function}
\description{
  Call the function \code{\link[MASS]{isoMDS}} and preserve labels.

  As of R version 1.5.0 you don't need this function. You can call
  \code{\link[MASS]{isoMDS}} directly, and labels will be preserved.
}
\usage{
  ISOMDS(dif, dim, y = cmdscale(dif, dim), \dots)
}
\arguments{
  \item{dif}{an object of class \code{dist}, with labels stored in the
    attribute \code{Labels}.}
  \item{dim}{the dimension of the space which the data are to be
  represented in.}
\item{y}{an initial configuration. If none is supplied, \code{\link[stats]{cmdscale}}
  is used to provide the classical solution.}
  \item{\dots}{more arguments to the function \code{\link[MASS]{isoMDS}}.}
}
\value{
  A matrix whose rows give the coordinates of each vector,
  with labels stored as rownames.
}
\references{
  RuG/L04 - software for dialectometrics and cartography: \url{http://www.let.rug.nl/~kleiweg/L04/}
}
\seealso{
  \code{\link[MASS]{isoMDS}},
  \code{\link{MDS}},
  \code{\link{SAMMON}}
}
\examples{\dontrun{
data(PA)
vec <- ISOMDS(PA, 2)
plot(vec, type = "n", xlab = "", ylab = "")
text(vec, rownames(vec), cex = 0.5)

vec8 <- ISOMDS(PA, 8)
d2 <- dist(vec)
d8 <- dist(vec8)
cor(PA, d2)
cor(PA, d8)

plot(range(PA), range(d2, d8), type = "n",
     xlab = "PA", ylab = "dist( isoMDS( PA ) )")
points(PA, d2, pch = 20, cex = 0.5, col = "black")
points(PA, d8, pch = 20, cex = 0.5, col = "blue")
legend(min(PA), max(d2, d8),
       c("dim = 2", "dim = 8"), fill = c("black", "blue"))
}}
\keyword{multivariate}
