\name{clustermap}
\alias{clustermap}
\title{Plot a clustering-based partitioning on a topographic map}
\description{
  Hierarchical clustering is used to derive a partitioning, which is used
  to plot a coloured topographic map. 
}
\usage{
clustermap(coo, dst, method = "ward.D2", k = 2, col = rainbow(k),
           labels = "dots", cex = 1, seq = 25:1, bwlim = .55, map = NULL,
           xlab = NULL, ylab = NULL, \dots)
}
\arguments{
  \item{coo}{a dataframe with x- and y-coordinates of locations stored in the first
    two columns, and names of locations stored as rownames.}
  \item{dst}{a dissimilarity structure as produced by the
    \code{\link[stats]{dist}} function, with names stored in the attribute
    \code{"Labels"}.}
  \item{method}{any of the methods to the \code{\link[stats]{hclust}} function.}
  \item{k}{desired number of groups.}
  \item{col}{a vector of size \code{k}, with colours for each cluster.}
  \item{labels}{what to use as labels.
    This is either a word: one of \code{"none"} (no labels),
    \code{"names"} (use rownames of argument \code{coo}), or
    \code{"dots"} (use dots); or a vector of labels ordered in
    accordance with the data in argument \code{coo}.
  }
  \item{cex}{the size of the labels relative to the default text size.}
  \item{seq}{a sequence of decreasing sizes of the area to fill around each
    location, relative to the default text size.}
  \item{bwlim}{a value between 0 and 1, determining the point to switch
    between white labels and black labels, relative to the background
    colour interpreted as a grey value between 0 and 1.}
  \item{map}{an optional two-column matrix with a set of line segments,
    used to draw a map. See \code{\link[graphics]{lines}} for the use of NA
    values.}
  \item{xlab}{a title for the x axis.}
  \item{ylab}{a title for the y axis.}
  \item{\dots}{further arguments to the \code{\link[graphics]{plot}} function.}
}
\value{
  None.
}
\references{
  RuG/L04 - software for dialectometrics and cartography: \url{http://www.let.rug.nl/~kleiweg/L04/}
}
\seealso{
  \code{\link{cccmap}},
  \code{\link{linkmap}},
  \code{\link{mdsmap}},
  \code{\link{mean.asp}}
}
\examples{
data(PA)
data(PA.coo)
data(PA.map)
asp <- mean.asp(PA.map[, 2])
clustermap(PA.coo[, 1:2], PA, labels = PA.coo$idx, k = 4,
           main = "Pennsylvania, USA",
           asp = asp, map = PA.map)
}
\keyword{hplot}
