\name{linkmap}
\alias{linkmap}
\title{Plot a set of links on a topographic map}
\description{
  Small differences are represented as dark lines on a topographic map. 
}
\usage{
linkmap(coo, dst, labels = "dots", cex = 1, limit = .25,
        shift = .2, separate = 10, asp = NA, nmax = NA, map = NULL,
        xlab = NULL, ylab = NULL, col = gray(0:40/40), \dots)
}
\arguments{
  \item{coo}{a dataframe with x- and y-coordinates of locations stored in the first
    two columns, and names of locations stored as rownames.}
  \item{dst}{a dissimilarity structure as produced by the
    \code{\link[stats]{dist}} function, with names stored in the attribute
    \code{"Labels"}.}
  \item{labels}{what to use as labels.
    This is either a word: one of \code{"none"} (no labels),
    \code{"names"} (use rownames of argument \code{coo}), or
    \code{"dots"} (use dots); or a vector of labels ordered in
    accordance with the data in argument \code{coo}.
  }
  \item{cex}{the size of the labels relative to the default text size.}
  \item{limit}{only plot lines not longer than \code{limit} times the
    length of the longest line. Results may not be correct if \code{asp}
    is not set.}
  \item{shift}{contrast enhancement. A value between 0 and 1. A smaller
    value results in fewer visible lines.}
  \item{separate}{contrast enhancement. Some positive value. A value of
    1 will result in a gradual transition from light lines to dark
    lines, a value of 50 will result in a sharp separation of light and
    dark lines.}
  \item{asp}{the aspect ratio. See  \code{\link[graphics]{plot.window}}
    function.}
  \item{nmax}{maximum number of lines to draw. The actual number of
    lines drawn may be less than this number if \code{limit} is less
    than 1.}
  \item{map}{an optional two-column matrix with a set of line segments,
    used to draw a map. See \code{\link[graphics]{lines}} for the use of NA
    values.}
  \item{xlab}{a title for the x axis.}
  \item{ylab}{a title for the y axis.}
  \item{col}{a colour palette to use for the lines, from dark to light.}
  \item{\dots}{further arguments to the \code{\link[graphics]{plot}} function.}
}
\value{
  None.
}
\references{
  RuG/L04 - software for dialectometrics and cartography: \url{http://www.let.rug.nl/~kleiweg/L04/}
}
\seealso{
  \code{\link{cccmap}},
  \code{\link{clustermap}},
  \code{\link{mdsmap}},
  \code{\link{mean.asp}}
}
\examples{
data(PA)
data(PA.coo)
data(PA.map)
asp <- mean.asp(PA.map[, 2])
linkmap(PA.coo[, 1:2], PA, labels = PA.coo$idx,
        main = "Pennsylvania, USA",
        nmax = 600, limit = .2, separate = 20, asp = asp, map = PA.map)
}
\keyword{hplot}
